
/*
 * Random GNOME background changer
 *
 * Copyright (c) 2004 Tomasz Torcz <zdzichu@irc.pl>
 * Licensed under the Open Software License version 2.0
 *
 * Compilation:
 * $ mcs -pkg:gconf-sharp-2.0 backchanger.cs
 *
 * Changes:
 * - 2006.09.06  Jacob Alberty <jacob.alberty // vetmanage.com>
 *               fix avoiding of deleted wallpapers (use 'Value' instead of 'ToString()')
 */

using System;
using System.Xml;
using GConf;

class BackChanger {
	public static void Main(string[] args) {
		XmlDocument background_file  = new XmlDocument();
		XmlNodeList backgrounds;
		XmlNode new_wallpaper;
		GConf.Client gclient;
		string BASE = "/desktop/gnome/background/";

		try {
			background_file.Load(Environment.GetEnvironmentVariable("HOME") +
					"/.gnome2/backgrounds.xml");

			backgrounds = background_file.GetElementsByTagName("wallpaper");
			do {
				new_wallpaper = backgrounds[(new Random()).Next(backgrounds.Count)];
			} while (new_wallpaper.Attributes["deleted"].Value == "true");

			gclient = new GConf.Client();
			foreach (XmlNode node in new_wallpaper.ChildNodes) {
				switch (node.Name) {
					case "filename":
						gclient.Set(BASE + "picture_filename", node.InnerText);
						break;
					case "options":
						gclient.Set(BASE + "picture_options", node.InnerText);
						break;
					case "shade_type":
						gclient.Set(BASE + "color_shading_type", node.InnerText);
						break;
					case "pcolor":
						gclient.Set(BASE + "primary_color", node.InnerText);
						break;
					case "scolor":
						gclient.Set(BASE + "secondary_color", node.InnerText);
						break;
				}
			}
			gclient.SuggestSync();

		} catch (Exception e) {
			Console.WriteLine("Some error occured: " + e.ToString());
		}
	}
}
